Combobox class

Constructors

Combobox({required List<ComboboxGroup> groups, required String headerValue})

Properties

groups List<ComboboxGroup>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headerValue String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<ComboboxGroup>? groups, String? headerValue}) Combobox
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited