ComboboxGroupItem class
Constructors
- ComboboxGroupItem({required String name, required String id, required bool isChecked})
Properties
Methods
-
copyWith(
{String? name, String? id, bool? isChecked}) → ComboboxGroupItem -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited